package org.jboss.qe.cxf.ws.jms.jms;

import org.apache.activemq.artemis.api.jms.ActiveMQJMSClient;
import org.apache.activemq.artemis.jms.client.ActiveMQConnectionFactory;
import org.apache.cxf.transport.jms.ConnectionFactoryFeature;

import javax.jms.ConnectionFactory;
import javax.xml.namespace.QName;
import javax.xml.ws.Service;
import javax.xml.ws.WebServiceFeature;

import java.io.File;
import java.io.IOException;
import java.net.URL;

import lombok.extern.slf4j.Slf4j;

@Slf4j
public class AbstractSoapJmsTest {

	protected static final String NAMESPACE = "http://cxf.apache.org/jms_greeter";
	protected static final String USERNAME = System.getProperty("external.broker.username");
	protected static final String PASSWORD = System.getProperty("external.broker.password");
	protected static String connectionUrl = System.getProperty("soap.jms.connection.url");

	public static final String REQUEST = "Martin";
	public static final String RESPONSE_TEMPLATE = "Hello %s! [%s]";

	protected <T> T getWebServiceProxy(Class<T> clazz, String serviceName, String portName, WebServiceFeature... features) throws Exception {
		final URL wsdlURL = new File("target/classes/wsdl/jms_greeter.wsdl").toURI().toURL();
		final QName serviceQname = new QName(NAMESPACE, serviceName);
		final QName portQname = new QName(NAMESPACE, portName);
		final Service service = Service.create(wsdlURL, serviceQname);
		return service.getPort(portQname, clazz, features);
	}

	protected ConnectionFactoryFeature createConnectionFactoryFeature() throws Exception {
		return new ConnectionFactoryFeature(getConnectionFactory());
	}

	protected ConnectionFactory getConnectionFactory() throws Exception {
		final ActiveMQConnectionFactory cf = ActiveMQJMSClient.createConnectionFactory(connectionUrl, "broker");
		cf.setUser(USERNAME);
		cf.setPassword(PASSWORD);
		return cf;
	}
}
